delu.random
===========

.. currentmodule:: delu.random

.. automodule:: delu.random

.. autosummary::
    :nosignatures:
    :toctree: generated
    :template: function.rst

    seed
    get_state
    set_state
    preserve_state
